@@ -14,7 +14,12 @@
 
 GetBalanceSheet <- function(symbol, year) {
      
-     balance.sheet.descriptions <- c("CONSOLIDATED BALANCE SHEET", "CONSOLIDATED BALANCE SHEETS", "CONSOLIDATED STATEMENT OF FINANCIAL POSITION", "CONSOLIDATED STATEMENTS OF FINANCIAL POSITION")
+     balance.sheet.descriptions <- c("CONSOLIDATED BALANCE SHEET", 
+                                     "CONSOLIDATED BALANCE SHEETS", 
+                                     "CONSOLIDATED STATEMENT OF FINANCIAL POSITION", 
+                                     "CONSOLIDATED STATEMENTS OF FINANCIAL POSITION",
+                                     "BALANCE SHEETS",
+                                     "CONSOLIDATED FINANCIAL POSITION")
      
      GetFinancial(balance.sheet.descriptions, symbol, year)
 }
